@@ -26,7 +26,7 @@ class CustomOpenstfRegressor(OpenstfRegressor):
     def valid_kwargs() -> list[str]:
         ...
 
-    @property
+    @classmethod
     @abstractmethod
     def objective(self) -> Type[RegressorObjective]:
         ...
@@ -58,18 +58,7 @@ def is_custom_type(model_type):
 
 
 def create_custom_objective(
-    model: CustomOpenstfRegressor,
-    input_data: pd.DataFrame,
-    test_fraction=TEST_FRACTION,
-    validation_fraction=VALIDATION_FRACTION,
-    eval_metric=EVAL_METRIC,
-    verbose=False,
+    custom_model_path,
 ):
-    return model.objective(
-        model,
-        input_data=input_data,
-        test_fraction=test_fraction,
-        validation_fraction=validation_fraction,
-        eval_metric=eval_metric,
-        verbose=verbose,
-    )
+    model_class = load_custom_model(custom_model_path)
+    return model_class.objective()
