@@ -5,28 +5,34 @@
 import joblib
 import pandas as pd
 import structlog
+
 import openstef.postprocessing.postprocessing as postprocessing
-from openstef.data_classes.prediction_job import PredictionJobDataClass
-from openstef.model.regressors.dazls import Dazls
-from openstef.enums import ForecastType
 from openstef import PROJECT_ROOT
+from openstef.data_classes.prediction_job import PredictionJobDataClass
+from openstef.enums import ForecastType
+from openstef.model.regressors.dazls import Dazls
 
 # Set the path for the Dazls stored model
 DAZLS_STORED = PROJECT_ROOT / "openstef" / "data" / "dazls_stored.sav"
 
 
-def create_input(pj, input_data, weather_data):
-    """
-    This function prepares the input data, which will be used for the Dazls model prediction, so they will be
+def create_input(
+    pj: PredictionJobDataClass, input_data: pd.DataFrame, weather_data: pd.DataFrame
+) -> pd.DataFrame:
+    """This function prepares the input data.
+
+    This data will be used for the Dazls model prediction, so they will be
     according Dazls model requirements.
 
-    :param pj: pj (PredictionJobDataClass): Prediction job
-    :param input_data: (pd.DataFrame): Input forecast for the components forecast.
-    :param weather_data: (pd.DataFrame): Weather data with 'radiation' and 'windspeed_100m' columns
+    Args:
+        pj: Prediction job
+        input_data: Input forecast for the components forecast.
+        weather_data: Weather data with 'radiation' and 'windspeed_100m' columns
+
+    Returns:
+        It outputs a dataframe which will be used for the Dazls prediction function.
 
-    :return: input_df (pd.Dataframe): It outputs a dataframe which will be used for the Dazls prediction function.
     """
-
     # Prepare raw input data
     input_df = (
         weather_data[["radiation", "windspeed_100m"]]
@@ -58,26 +64,26 @@ def create_input(pj, input_data, weather_data):
 
 
 def create_components_forecast_pipeline(
-    pj: PredictionJobDataClass, input_data, weather_data
-):
-    """
-    Pipeline for creating a component forecast using Dazls prediction model
+    pj: PredictionJobDataClass, input_data: pd.DataFrame, weather_data: pd.DataFrame
+) -> pd.DataFrame:
+    """Pipeline for creating a component forecast using Dazls prediction model.
 
     Args:
-        pj (PredictionJobDataClass): Prediction job
-        input_data (pd.DataFrame): Input forecast for the components forecast.
-        weather_data (pd.DataFrame): Weather data with 'radiation' and 'windspeed_100m' columns
+        pj: Prediction job
+        input_data: Input forecast for the components forecast.
+        weather_data: Weather data with 'radiation' and 'windspeed_100m' columns
 
     Returns:
-        pd.DataFrame with component forecasts. The dataframe contains these columns:
-                "forecast_wind_on_shore",
-                "forecast_solar",
-                "forecast_other",
-                "pid",
-                "customer",
-                "description",
-                "type",
-                "algtype"
+        DataFrame with component forecasts. The dataframe contains these columns;
+        "forecast_wind_on_shore",
+        "forecast_solar",
+        "forecast_other",
+        "pid",
+        "customer",
+        "description",
+        "type",
+        "algtype"
+
     """
     logger = structlog.get_logger(__name__)
     logger.info("Make components prediction", pid=pj["id"])
